@@ -27,7 +27,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include <telepathy-glib/file-transfer-channel.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "empathy-contact.h"
 
