@@ -21,7 +21,7 @@
 
 #include <gio/gio.h>
 
-#include <telepathy-glib/account.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 G_BEGIN_DECLS
 
