@@ -21,42 +21,30 @@
  *          Danielle Madeley <danielle.madeley@collabora.co.uk>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <sys/stat.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 
-#include <telepathy-glib/telepathy-glib.h>
-#include <folks/folks.h>
-
-#include <libempathy/empathy-contact.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-chatroom-manager.h>
-#include <libempathy/empathy-chatroom.h>
 #include <libempathy/empathy-gsettings.h>
-#include <libempathy/empathy-individual-manager.h>
 #include <libempathy/empathy-gsettings.h>
 #include <libempathy/empathy-status-presets.h>
 #include <libempathy/empathy-presence-manager.h>
 
-#include <libempathy-gtk/empathy-live-search.h>
 #include <libempathy-gtk/empathy-contact-blocking-dialog.h>
 #include <libempathy-gtk/empathy-contact-search-dialog.h>
 #include <libempathy-gtk/empathy-geometry.h>
 #include <libempathy-gtk/empathy-gtk-enum-types.h>
 #include <libempathy-gtk/empathy-individual-dialogs.h>
-#include <libempathy-gtk/empathy-individual-store-manager.h>
-#include <libempathy-gtk/empathy-roster-model.h>
 #include <libempathy-gtk/empathy-roster-model-manager.h>
 #include <libempathy-gtk/empathy-roster-view.h>
 #include <libempathy-gtk/empathy-new-message-dialog.h>
 #include <libempathy-gtk/empathy-new-call-dialog.h>
 #include <libempathy-gtk/empathy-log-window.h>
 #include <libempathy-gtk/empathy-presence-chooser.h>
-#include <libempathy-gtk/empathy-sound-manager.h>
 #include <libempathy-gtk/empathy-ui-utils.h>
 
 #include "empathy-accounts-dialog.h"
@@ -65,7 +53,6 @@
 #include "empathy-roster-window.h"
 #include "empathy-preferences.h"
 #include "empathy-about-dialog.h"
-#include "empathy-debug-window.h"
 #include "empathy-new-chatroom-dialog.h"
 #include "empathy-chatrooms-window.h"
 #include "empathy-event-manager.h"
